import { Effect } from 'effect';
import type { InvalidCustomTypeError } from '../config/get-custom-types';
import type { DeprecatedTypesError, RenamedWorkspaceTypeError } from '../config/get-enabled-types';
import type { Ctx } from '../get-context';
import type { NoSourcesFoundError } from '../get-package-json-files/get-file-paths';
import type { GlobError } from '../io/glob-sync';
import type { ReadFileError } from '../io/read-file-sync';
import type { JsonParseError } from '../io/read-json-file-sync';
import type { WriteFileError } from '../io/write-file-sync';
import type { SemverGroup } from '../semver-group';
import type { VersionGroup } from '../version-group';
type R = Effect.Effect<never, never, void>;
export interface ErrorHandlers {
    DeprecatedTypesError(err: DeprecatedTypesError): R;
    InvalidCustomTypeError(err: InvalidCustomTypeError): R;
    RenamedWorkspaceTypeError(err: RenamedWorkspaceTypeError): R;
    SemverGroupConfigError(err: SemverGroup.ConfigError): R;
    VersionGroupConfigError(err: VersionGroup.ConfigError): R;
    GlobError(err: GlobError): R;
    JsonParseError(err: JsonParseError): R;
    NoSourcesFoundError(err: NoSourcesFoundError): R;
    ReadFileError(err: ReadFileError): R;
    WriteFileError(err: WriteFileError): R;
}
export declare function chainErrorHandlers(ctx: Ctx, errorHandlers: ErrorHandlers): {
    DeprecatedTypesError: (err: DeprecatedTypesError) => Effect.Effect<never, never, Ctx>;
    GlobError: (err: GlobError) => Effect.Effect<never, never, Ctx>;
    InvalidCustomTypeError: (err: InvalidCustomTypeError) => Effect.Effect<never, never, Ctx>;
    JsonParseError: (err: JsonParseError) => Effect.Effect<never, never, Ctx>;
    NoSourcesFoundError: (err: NoSourcesFoundError) => Effect.Effect<never, never, Ctx>;
    ReadFileError: (err: ReadFileError) => Effect.Effect<never, never, Ctx>;
    RenamedWorkspaceTypeError: (err: RenamedWorkspaceTypeError) => Effect.Effect<never, never, Ctx>;
    SemverGroupConfigError: (err: SemverGroup.ConfigError) => Effect.Effect<never, never, Ctx>;
    VersionGroupConfigError: (err: VersionGroup.ConfigError) => Effect.Effect<never, never, Ctx>;
    WriteFileError: (err: WriteFileError) => Effect.Effect<never, never, Ctx>;
};
export declare const defaultErrorHandlers: ErrorHandlers;
export {};
