"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseSpecifier = void 0;
const effect_1 = require("effect");
const _1 = require(".");
const non_semver_error_1 = require("./lib/non-semver-error");
const parse_specifier_1 = require("./lib/parse-specifier");
class BaseSpecifier {
    constructor(data) {
        /** should be overridden by sub classes */
        this._tag = 'BaseSpecifier';
        this.raw = data.raw;
        this.instance = data.instance;
    }
    /**
     * Parse the raw version specifier using
     * https://github.com/npm/npm-package-arg
     */
    parse() {
        const name = this.instance.name;
        const raw = this.raw;
        const packageJsonFile = this.instance.packageJsonFile;
        return (0, effect_1.pipe)(effect_1.Effect.try(() => (0, parse_specifier_1.parseSpecifier)(name, raw, packageJsonFile)), effect_1.Effect.tapError(() => effect_1.Effect.logError(`parseSpecifier threw on ${name}@${raw} at ${packageJsonFile.jsonFile.shortPath}`)));
    }
    /** Return the version portion if it is valid semver */
    getSemver() {
        return non_semver_error_1.NonSemverError.asEffect(this);
    }
    /** Get a new `Specifier` from the given semver version applied to this one */
    setSemver(_version) {
        return non_semver_error_1.NonSemverError.asEffect(this);
    }
    /** Apply the given specifier to a new one with this instance bound to it */
    replaceWith(specifier) {
        return _1.Specifier.create(this.instance, specifier.raw);
    }
}
exports.BaseSpecifier = BaseSpecifier;
